# PulpRpmClient::ContentAdvisoriesApi

All URIs are relative to *https://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](ContentAdvisoriesApi.md#create) | **POST** /pulp/api/v3/content/rpm/advisories/ | Create an update record
[**list**](ContentAdvisoriesApi.md#list) | **GET** /pulp/api/v3/content/rpm/advisories/ | List update records
[**read**](ContentAdvisoriesApi.md#read) | **GET** {rpm_update_record_href} | Inspect an update record



## create

> AsyncOperationResponse create(opts)

Create an update record

Trigger an asynchronous task to create content,optionally create new repository version.

### Example

```ruby
# load the gem
require 'pulp_rpm_client'
# setup authorization
PulpRpmClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpRpmClient::ContentAdvisoriesApi.new
opts = {
  file: File.new('/path/to/file'), # File | An uploaded file that may be turned into the artifact of the content unit.
  repository: 'repository_example' # String | A URI of a repository the new content unit should be associated with.
}

begin
  #Create an update record
  result = api_instance.create(opts)
  p result
rescue PulpRpmClient::ApiError => e
  puts "Exception when calling ContentAdvisoriesApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **file** | **File**| An uploaded file that may be turned into the artifact of the content unit. | [optional] 
 **repository** | **String**| A URI of a repository the new content unit should be associated with. | [optional] 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: multipart/form-data, application/x-www-form-urlencoded
- **Accept**: application/json


## list

> PaginatedrpmUpdateRecordResponseList list(opts)

List update records

A ViewSet for UpdateRecord.  Define endpoint name which will appear in the API endpoint for this content type. For example::     http://pulp.example.com/pulp/api/v3/content/rpm/advisories/  Also specify queryset and serializer for UpdateRecord.

### Example

```ruby
# load the gem
require 'pulp_rpm_client'
# setup authorization
PulpRpmClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpRpmClient::ContentAdvisoriesApi.new
opts = {
  id: 'id_example', # String | Filter results where id matches value
  id__in: ['id__in_example'], # Array<String> | Filter results where id is in a comma-separated list of values
  limit: 56, # Integer | Number of results to return per page.
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  repository_version: 'repository_version_example', # String | Repository Version referenced by HREF
  repository_version_added: 'repository_version_added_example', # String | Repository Version referenced by HREF
  repository_version_removed: 'repository_version_removed_example', # String | Repository Version referenced by HREF
  severity: 'severity_example', # String | Filter results where severity matches value
  severity__in: ['severity__in_example'], # Array<String> | Filter results where severity is in a comma-separated list of values
  severity__ne: 'severity__ne_example', # String | Filter results where severity not equal to value
  status: 'status_example', # String | Filter results where status matches value
  status__in: ['status__in_example'], # Array<String> | Filter results where status is in a comma-separated list of values
  status__ne: 'status__ne_example', # String | Filter results where status not equal to value
  type: 'type_example', # String | Filter results where type matches value
  type__in: ['type__in_example'], # Array<String> | Filter results where type is in a comma-separated list of values
  type__ne: 'type__ne_example', # String | Filter results where type not equal to value
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List update records
  result = api_instance.list(opts)
  p result
rescue PulpRpmClient::ApiError => e
  puts "Exception when calling ContentAdvisoriesApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| Filter results where id matches value | [optional] 
 **id__in** | [**Array&lt;String&gt;**](String.md)| Filter results where id is in a comma-separated list of values | [optional] 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **repository_version** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_added** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_removed** | **String**| Repository Version referenced by HREF | [optional] 
 **severity** | **String**| Filter results where severity matches value | [optional] 
 **severity__in** | [**Array&lt;String&gt;**](String.md)| Filter results where severity is in a comma-separated list of values | [optional] 
 **severity__ne** | **String**| Filter results where severity not equal to value | [optional] 
 **status** | **String**| Filter results where status matches value | [optional] 
 **status__in** | [**Array&lt;String&gt;**](String.md)| Filter results where status is in a comma-separated list of values | [optional] 
 **status__ne** | **String**| Filter results where status not equal to value | [optional] 
 **type** | **String**| Filter results where type matches value | [optional] 
 **type__in** | [**Array&lt;String&gt;**](String.md)| Filter results where type is in a comma-separated list of values | [optional] 
 **type__ne** | **String**| Filter results where type not equal to value | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedrpmUpdateRecordResponseList**](PaginatedrpmUpdateRecordResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## read

> RpmUpdateRecordResponse read(rpm_update_record_href, opts)

Inspect an update record

A ViewSet for UpdateRecord.  Define endpoint name which will appear in the API endpoint for this content type. For example::     http://pulp.example.com/pulp/api/v3/content/rpm/advisories/  Also specify queryset and serializer for UpdateRecord.

### Example

```ruby
# load the gem
require 'pulp_rpm_client'
# setup authorization
PulpRpmClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpRpmClient::ContentAdvisoriesApi.new
rpm_update_record_href = 'rpm_update_record_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect an update record
  result = api_instance.read(rpm_update_record_href, opts)
  p result
rescue PulpRpmClient::ApiError => e
  puts "Exception when calling ContentAdvisoriesApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **rpm_update_record_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**RpmUpdateRecordResponse**](RpmUpdateRecordResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

